@@ -1,8 +1,8 @@
 // This defines the interfaces for the pyqtSignal type.
 //
-// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
-// This file is part of PyQt5.
+// This file is part of PyQt6.
 // 
 // This file may be used under the terms of the GNU General Public License
 // version 3.0 as published by the Free Software Foundation and appearing in
@@ -57,20 +57,23 @@ typedef struct _qpycore_pyqtSignal {
     Chimera::Signature *parsed_signature;
 
     // An optional emitter.
-    pyqt5EmitFunc emitter;
+    pyqt6EmitFunc emitter;
 
     // The non-signal overloads (if any).  This is only set for the default.
     PyMethodDef *non_signals;
 } qpycore_pyqtSignal;
 
 
-extern PyTypeObject qpycore_pyqtSignal_Type;
-
 int qpycore_get_lazy_attr(const sipTypeDef *td, PyObject *dict);
 
 }
 
 
+// The type object.
+extern PyTypeObject *qpycore_pyqtSignal_TypeObject;
+
+
+bool qpycore_pyqtSignal_init_type();
 qpycore_pyqtSignal *qpycore_pyqtSignal_New(const char *signature,
         bool *fatal = 0);
 qpycore_pyqtSignal *qpycore_find_signal(qpycore_pyqtSignal *ps,
